==> hbase-1.7.2-src.tar.gz: hbase-1.7.2/hbase-server/src/test/java/org/apache/hadoop/hbase/util/LauncherSecurityManager.java <==
/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hbase.util;

import java.security.Permission;

/**
  * class for masquerading System.exit(int).
  * Use for test main method with System.exit(int )
  * usage:
  * new LauncherSecurityManager();
  *    try {
  *      CellCounter.main(args);
  *      fail("should be exception");
  *    } catch (SecurityException e) {
  *      assert(.,e.getExitCode());
  *    }
 */
public class LauncherSecurityManager extends SecurityManager {

  private int exitCode;
  private SecurityManager securityManager;

  public LauncherSecurityManager() {
    this(null);
  }

  public LauncherSecurityManager(SecurityManager securityManager) {
    this.securityManager = securityManager;
    reset();
  }

  @Override
  public void checkPermission(Permission perm, Object context) {
    if (securityManager != null) {
      // check everything with the original SecurityManager
      securityManager.checkPermission(perm, context);
    }
  }

  @Override
  public void checkPermission(Permission perm) {
    if (securityManager != null) {
      // check everything with the original SecurityManager
      securityManager.checkPermission(perm);
    }
  }

  @Override
  public void checkExit(int status) throws SecurityException {
    exitCode = status;
    throw new SecurityException("Intercepted System.exit(" + status + ")");
  }

  public  int getExitCode() {
    return exitCode;
  }

  public void reset() {
    exitCode = 0;
  }

}

==> hbase-2.5.13-src.tar.gz: hbase-2.5.13/hbase-server/src/test/java/org/apache/hadoop/hbase/util/LauncherSecurityManager.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.util;

import java.security.Permission;

/**
 * class for masquerading System.exit(int). Use for test main method with System.exit(int ) usage:
 * new LauncherSecurityManager(); try { CellCounter.main(args); fail("should be exception"); } catch
 * (SecurityException e) { assert(.,e.getExitCode()); }
 */
public class LauncherSecurityManager extends SecurityManager {

  private int exitCode;
  private SecurityManager securityManager;

  public LauncherSecurityManager() {
    reset();
  }

  @Override
  public void checkPermission(Permission perm, Object context) {
    if (securityManager != null) {
      // check everything with the original SecurityManager
      securityManager.checkPermission(perm, context);
    }
  }

  @Override
  public void checkPermission(Permission perm) {
    if (securityManager != null) {
      // check everything with the original SecurityManager
      securityManager.checkPermission(perm);
    }
  }

  @Override
  public void checkExit(int status) throws SecurityException {
    exitCode = status;
    throw new SecurityException("Intercepted System.exit(" + status + ")");
  }

  public int getExitCode() {
    return exitCode;
  }

  public void reset() {
    exitCode = 0;
  }

}
